@@ -201,7 +201,7 @@ unsigned long long PSt_size;
    list.  (the use of a single list is for historical reasons, it is
    not the most ovbious design for the current needs)
  */
-#define PATTYPE_MATCH 0 
+#define PATTYPE_MATCH 0
 #define PATTYPE_NOMATCH 1
 #define PATTYPE_EXT 2
 
@@ -392,7 +392,7 @@ typedef struct dir
   time_t d_mtime;		/* Modification time */
   char *d_name;			/* Pathname of directory */
 } Dir;
- 
+
 
 
 /*
@@ -438,6 +438,7 @@ int namecmp (char *, Stat *);
 int namecmp_ext (char *);
 int nameopt (char *);
 void next (int, char *);
+int runpromptscript (char *);
 void nextask (char *, char *, int);
 void nextclos (void );
 int nextopen (int);
@@ -446,8 +447,8 @@ int openotty (char *, Stat *, Link *, int, int);
 int openqtty (void);
 int options (int, char **, char *);
 VOIDFN out (char **);
-void outalloc (uint);
-uint outavail (char **);
+void outalloc (size_t);
+size_t outavail (char **);
 int outdata (int, char*, off_t);
 
 void outdatazip (int, char*, off_t); /* added KH */
@@ -456,7 +457,7 @@ void outdatamem (char *, off_t); /* added KH */
 void memreset(void); /* added KH */
 int memread(char *buf,int count); /* added KH */
 void memfree(void); /* added KH */
-int nameaddfile(char *, int); /* added KH */
+int nameaddfile(char *, int, int); /* added KH */
 
 void outeof (char *, uint);
 void outflush (int);
@@ -474,13 +475,14 @@ int pipeopen (int );
 void pipewait (void);
 void prsize (FILE *, ulonglong);
 VOIDFN readcheck (char **);
+VOIDFN process_arname (char *);
 #ifndef MKDIR
 int rmdir (char *);
 #endif
-#if !defined (linux) && !defined(__FreeBSD__) && !defined(sun)
+#if !defined (linux) && !defined(__FreeBSD__) && !defined(sun) && !defined(__CYGWIN32__)
 VOIDFN (*signal ())();
 #endif
-     int fswrite (int, char*, uint);
+     ssize_t fswrite (int, char*, size_t);
      char *syserr (void);
      VOIDFN toc (char **);
      void tocentry (char *, Stat *);
@@ -496,7 +498,7 @@ VOIDFN (*signal ())();
      int xwait (int, char *, int);
      void mail(char *who,int vol,char *archive);
 
-int writeall(int, const char*, unsigned int);
+ssize_t writeall(int, const char*, size_t);
 int incheckentry(char *, Stat *);
 int incheckdata (int fd, off_t size, char *name, Stat *asb, int comp);
 Link * linkinode16 (dev_t dev, ino_t ino);
@@ -504,6 +506,7 @@ int opencontrolscript (char *name);
 
 int openincheck(char *, Stat *, int *,int);
 void mayberewind(void);
+int fixinsecure (char *);
 
 extern  void add_arg(char *arg);
 extern  char *compress_arg_list[];
@@ -530,3 +533,5 @@ extern int readcompexts(char*);
 ulonglong optsize (char *);
 void update_aruntil(void);
 extern ulonglong maxsizetocompress;
+extern short noglob;
+extern short flag0;
