@@ -1,5 +1,5 @@
-#define VERSION	"2.5"
-#define DATE	"21 Dec 2003"
+#define VERSION	"2.5.2"
+#define DATE	"30 Nov 2018"
 
 /*
  * Version 1.68		               1985	Mark Brukhartz
@@ -22,4 +22,7 @@
  * Version 2.4.7.9beta4         04 Dec 2002     Koen Holtman
  * Version 2.4.8.beta1          14 Dec 2003     Koen Holtman
  * Version 2.5                  21 Dec 2003     Koen Holtman
+ * Version 2.5.1                05 Feb 2012     Koen Holtman
+ * Version 2.5.1-2              09 Aug 2012     Koen Holtman
+ * Version 2.5.2                30 Nov 2018     Koen Holtman
  */
